/*
 *  linux/kernel/kcjprintk.c
 *
 * This software is contributed or developed by KYOCERA Corporation.
 * (C) 2012 KYOCERA Corporation
 *
 * Modified to make sys_syslog() more flexible: added commands to
 * return the last 4k of kernel messages, regardless of whether
 * they've been read or not.  Added option to suppress kernel printk's
 * to the console.  Added hook for sending the console messages
 * elsewhere, in preparation for a serial line console (someday).
 * Ted Ts'o, 2/11/93.
 * Modified for sysctl support, 1/8/97, Chris Horn.
 * Fixed SMP synchronization, 08/08/99, Manfred Spraul
 *     manfred@colorfullife.com
 * Rewrote bits to get rid of console_lock
 *	01Mar01 Andrew Morton
 */

#include <linux/kernel.h>
#include <linux/mm.h>
#include <linux/tty.h>
#include <linux/tty_driver.h>
#include <linux/console.h>
#include <linux/init.h>
#include <linux/jiffies.h>
#include <linux/nmi.h>
#include <linux/module.h>
#include <linux/moduleparam.h>
#include <linux/interrupt.h>			/* For in_interrupt() */
#include <linux/delay.h>
#include <linux/smp.h>
#include <linux/security.h>
#include <linux/bootmem.h>
#include <linux/syscalls.h>
#include <linux/kexec.h>
#include <linux/kcjprintk.h>

#include <asm/uaccess.h>

/**
 * printk - print a kernel message
 * @fmt: format string
 *
 * This is printk().  It can be called from any context.  We want it to work.
 *
 * We try to grab the console_sem.  If we succeed, it's easy - we log the output and
 * call the console drivers.  If we fail to get the semaphore we place the output
 * into the log buffer and return.  The current holder of the console_sem will
 * notice the new output in release_console_sem() and will send it to the
 * consoles before releasing the semaphore.
 *
 * One effect of this deferred printing is that code which calls printk() and
 * then changes console_loglevel may break. This is because console_loglevel
 * is inspected when the actual printing occurs.
 *
 * See also:
 * printf(3)
 *
 * See the vsnprintf() documentation for format string extensions over C99.
 */

static  int kcjprintk_OutputMode=0;

int kcjprintk_getOutputMode(void)
{
    int mode = false;
    if(kcjprintk_OutputMode != false)
    {
        mode = true;
    }
    /*printk("kcjprintk_OutputMode (get)== %d\n",mode);*/
    return (mode);
}
EXPORT_SYMBOL(kcjprintk_getOutputMode);

void kcjprintk_setOutputMode(int mode)
{
    /*printk("KcjLogOutputMode (before)== %d\n",kcjprintk_OutputMode);*/
    if(mode != 0)
    {
        kcjprintk_OutputMode=true;
    }else{
        kcjprintk_OutputMode=false;
    }
    /*printk("KcjLogOutputMode (after)== %d\n",kcjprintk_OutputMode);*/
}
EXPORT_SYMBOL(kcjprintk_setOutputMode);


asmlinkage int kcjprintk(const char *fmt, ...)
{
	va_list args;
	int r;

    if( kcjprintk_getOutputMode() == true )
    {
	    va_start(args, fmt);
	    r = vprintk(fmt, args);
	    va_end(args);
    }
 	return 0;
}

EXPORT_SYMBOL(kcjprintk);
